@@ -3,8 +3,9 @@ package JQ::Lite;
 use strict;
 use warnings;
 use JSON::PP;
+use Data::Dumper;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
     my ($class, %opts) = @_;
@@ -17,7 +18,11 @@ sub new {
 sub run_query {
     my ($self, $json_text, $query) = @_;
     my $data = decode_json($json_text);
-
+    
+    if (!defined $query || $query =~ /^\s*\.\s*$/) {
+        return ($data);
+    }
+    
     my @parts = split /\|/, $query;
     @parts = map {
         s/^\s+|\s+$//g;
@@ -28,6 +33,36 @@ sub run_query {
     my @results = ($data);
     for my $part (@parts) {
         my @next_results;
+
+        # select(...) 対応
+        if ($part =~ /^select\((.+)\)$/) {
+            my $cond = $1;
+            @next_results = grep { _evaluate_condition($_, $cond) } @results;
+            @results = @next_results;
+            next;
+        }
+
+        # length 対応
+        if ($part eq 'length') {
+            @next_results = map {
+                ref $_ eq 'ARRAY' ? scalar(@$_) :
+                ref $_ eq 'HASH'  ? scalar(keys %$_) :
+                0
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
+        # keys 対応
+        if ($part eq 'keys') {
+            @next_results = map {
+                ref $_ eq 'HASH' ? [ sort keys %$_ ] : undef
+            } @results;
+            @results = @next_results;
+            next;
+        }
+
+        # 通常トラバース
         for my $item (@results) {
             push @next_results, _traverse($item, $part);
         }
@@ -43,13 +78,7 @@ sub _traverse {
     my @stack = ($data);
 
     for my $step (@steps) {
-        my $optional = ($step =~ s/\?\$// || $step =~ s/\?\$//g);
-        $optional = 1 if $step =~ s/\?\$//;
-        $optional = 1 if $step =~ s/\?\$//g;
-        $optional = 1 if $step =~ s/\?\$//;
-        $optional = 1 if $step =~ s/\?\$//g;
-        $optional = 1 if $step =~ s/\?$//;
-
+        my $optional = ($step =~ s/\?$//);
         my @new_stack;
 
         if ($step =~ /^(.*?)\[(\d+)\]$/) {
@@ -106,6 +135,54 @@ sub _traverse {
     return @stack;
 }
 
+sub _evaluate_condition {
+    my ($item, $cond) = @_;
+
+    # 例: .profile.country == "JP"
+    if ($cond =~ /^\s*\.(.+?)\s*(==|!=|>=|<=|>|<)\s*(.+?)\s*$/) {
+        my ($path, $op, $value_raw) = ($1, $2, $3);
+
+        my $value;
+        if ($value_raw =~ /^"(.*)"$/) {
+            $value = $1;
+        } elsif ($value_raw eq 'true') {
+            $value = JSON::PP::true;
+        } elsif ($value_raw eq 'false') {
+            $value = JSON::PP::false;
+        } elsif ($value_raw =~ /^-?\d+(\.\d+)?$/) {
+            $value = 0 + $value_raw;
+        } else {
+            $value = $value_raw;
+        }
+
+        # 新しく: _traverse を使って値を取得
+        my @values = _traverse($item, $path);
+        my $field_val = $values[0];  # 最初の値だけ比較（配列対応は後回し）
+
+        return eval {
+            return 0 unless defined $field_val;
+            my $is_number = ($field_val =~ /^-?\d+(\.\d+)?$/) && ($value =~ /^-?\d+(\.\d+)?$/);
+
+            if ($op eq '==') {
+                return $is_number ? $field_val == $value : $field_val eq $value;
+            } elsif ($op eq '!=') {
+                return $is_number ? $field_val != $value : $field_val ne $value;
+            } elsif ($op eq '>') {
+                return $field_val > $value;
+            } elsif ($op eq '>=') {
+                return $field_val >= $value;
+            } elsif ($op eq '<') {
+                return $field_val < $value;
+            } elsif ($op eq '<=') {
+                return $field_val <= $value;
+            }
+            return 0;
+        } || 0;
+    }
+
+    return 0;
+}
+
 1;
 __END__
 
