@@ -7,24 +7,18 @@ use FindBin;
 use lib "$FindBin::Bin/../lib";
 use JQ::Lite;
 
-# クエリをコマンドライン引数から取得
-my $query = shift or die "Usage: $0 '.query'
-";
-
-# 標準入力からJSONを読み込む
+my $query = shift or die "Usage: $0 '.query'\n";
 my $json_text = do { local $/; <STDIN> };
 
-# JQ::Lite を使ってクエリを実行
 my $jq = JQ::Lite->new;
 my @results = $jq->run_query($json_text, $query);
 
-# 出力
+my $pp = JSON::PP->new->utf8->canonical->pretty;
+
 for my $r (@results) {
     if (!defined $r) {
         print "null\n";
-    } elsif (ref $r eq '') {
-        print "$r\n";
     } else {
-        print encode_json($r), "\n";
+        print $pp->encode($r);  # ← すべて pretty print
     }
 }
